papaya
======

This django-backed library is intended as an authentication provider within an organization's internal services.

It contains:

* An LDAP-based authentication backend
* An OpenID provider, with autologin for trusted sites
* An OpenID consumer, with autologin to a predefined OpenID provider



License
-------

Copyright (C) 2009 Bolloré telecom
Copyright (C) 2014 Polyconseil
See AUTHORS file for a full list of contributors.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

